Follow refactoring of install-abandon command.

Bug: 16543552
Change-Id: I1f54254813fd7d7f4341b8815f816535a39de079
diff --git a/commandline.c b/commandline.c
index 96ea8c6..e1ff856 100644
--- a/commandline.c
+++ b/commandline.c
@@ -2041,11 +2041,11 @@
     }
 
 finalize_session:
     // Commit session if we streamed everything okay; otherwise destroy
     if (success) {
         snprintf(buf, sizeof(buf), "exec:pm install-commit %d", session_id);
     } else {
-        snprintf(buf, sizeof(buf), "exec:pm install-destroy %d", session_id);
+        snprintf(buf, sizeof(buf), "exec:pm install-abandon %d", session_id);
     }
 
     fd = adb_connect(buf);
@@ -2041,11 +2041,11 @@
 
 finalize_session:
-    // Commit session if we streamed everything okay; otherwise destroy
+    // Commit session if we streamed everything okay; otherwise abandon
     if (success) {
         snprintf(buf, sizeof(buf), "exec:pm install-commit %d", session_id);